@@ -7,7 +7,7 @@ from transformers import (
     BeamSearchScorer,
     PhrasalConstraint,
     ConstrainedBeamSearchScorer,
-    PreTrainedModel
+    PreTrainedModel,
 )
 import numpy as np
 import random
@@ -20,6 +20,7 @@ from torch import nn
 import torch.distributed as dist
 import copy
 
+
 def setup_seed(seed):
     if seed == -1:
         return
@@ -996,6 +997,7 @@ class NewGenerationMixin(GenerationMixin):
                 else:
                     this_peer_finished = True
 
+
 def init_stream_support():
     PreTrainedModel.generate = NewGenerationMixin.generate
     PreTrainedModel.sample_stream = NewGenerationMixin.sample_stream
